<?php
/**
 * @file
 * Contains \Drupal\bootstrap_simple_carousel\Form\EditForm.
 */

namespace Drupal\bootstrap_simple_carousel\Service;

use Drupal\file\Entity\File;

class CarouselService {

  static $service;

  /** @var \Drupal\Core\Render\Renderer */
  protected $renderer;

  protected function __construct() {
    $this->setRenderer(\Drupal::service('renderer'));
  }

  protected function __clone() {
  }

  /**
   * @return self
   */
  public static function getInstance() {
    if (empty(static::$service)) {
      static::$service = new static();
    }

    return static::$service;
  }

  /**
   * @param $renderer
   */
  public function setRenderer($renderer)
  {
    $this->renderer = $renderer;
  }

  /**
   * @param $image_id int
   * @param $image_style string
   * @param $params array
   *
   * @throws \Exception
   * @return string
   */
  public function renderImageById($image_id, $image_style = 'thumbnail', $params = []) {
    $image = '';
    $imageFile = File::load($image_id);

    if (!empty($imageFile)) {
      $imageTheme = [
        '#theme' => 'image_style',
        '#style_name' => $image_style,
        '#uri' => $imageFile->getFileUri(),
        '#alt' => $params['alt'] ?? '',
        '#title' => $params['title'] ?? '',
      ];

      $image = $this->renderer->render($imageTheme);
    }

    return $image;
  }

  /**
   * @param $url string
   * @param $title string
   * @param $attributes array
   *
   * @throws \Exception
   * @return string
   */
  public function renderLink($url, $title, $attributes = []) {
    $linkTheme = [
      '#type' => 'link',
      '#title' => $title,
      '#url' => $url,
      '#options' => [
        'attributes' => $attributes,
        'html' => FALSE,
      ],
    ];

    $link = $this->renderer->render($linkTheme);

    return $link;
  }

  public function getStatuses()
  {
    return [
      0 => t('Inactive'),
      1 => t('Active'),
    ];
  }

}